@@ -10,13 +10,14 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE);
-$VERSION = '1.03';
-$DATE = '2003/07/05';
+$VERSION = '1.05';
+$DATE = '2003/07/31';
 
 use File::Package;
 use File::Data;
 use DataPort::FileType::FormDB;
 use Cwd;
+use File::Spec;
 
 #######
 #
@@ -63,7 +64,7 @@ sub make_pm
          my $optionDB_record;
          my $optionDB_file = $self->load_db($options_pm, \$optionDB_record, \@optionDB );
          unless($optionDB_file) {
-             warn "Cannot load $optionDB_file\n";
+             warn "Cannot load $options_pm\n";
              return undef;
          }
           
@@ -96,6 +97,7 @@ sub make_pm
     
      my $success = 1;
      foreach $pm (@pm) {
+         print 'Processing ' . (join ' ',@targets) . " -pm=$pm\n" if( 1 < @pm );
          $self->{options}->{pm} = $pm;    
          unless ($self->make_targets( $targets_h, @targets)) {
              $success = 0;
@@ -136,7 +138,7 @@ sub make_targets
          my $formDB_record;
          my $formDB_file = $self->load_db($formDB_pm, \$formDB_record, \@formDB );
          unless($formDB_file) {
-             warn "Cannot load $formDB_file\n";
+             warn "Cannot load $formDB_pm\n";
              return undef;
          }
           
@@ -188,6 +190,7 @@ sub make_targets
                  
                  unless ($self->$method( @args )) {
                      $success = undef;
+                     warn( "Target $method failed.\n" );
                      last;
                  }
 
@@ -236,6 +239,7 @@ sub load_db
      no strict;
      $formDB_file = ${"${formDB_pm}::FILE"};
      use strict;
+     $formDB_file = File::Spec->rel2abs( $formDB_file );
 
      unless( $formDB_file ) {
          warn "No FILE variable in FormDB program module $formDB_pm.\n";
@@ -250,7 +254,7 @@ sub load_db
      my $dbh = new DataPort::FileType::FormDB( file => $fh );
      return undef unless( $dbh );
      unless ($dbh->get($formDB_array, $formDB_record)) {
-         unless( $formDB_record ) {
+         unless( $$formDB_record ) {
              warn( "Empty database for program module $formDB_pm.\n");
          }
          return undef;
@@ -259,13 +263,6 @@ sub load_db
      $dbh->finish( );
      @INC = @restore_inc;
 
-     ###### 
-     # Unescape any POD directives
-     #
-     for( my $i=1; $i < @$formDB_array; $i += 2) {
-         ${$formDB_array}[$i] =~ s/\n\\=/\n=/g;   
-     }
-
      return( $formDB_file );
 
 }
